==> kubernetes-model-kustomize-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/LabelFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LabelFluentImpl<A extends LabelFluent<A>> extends BaseFluent<A> implements LabelFluent<A>{
  public LabelFluentImpl() {
  }
  public LabelFluentImpl(Label instance) {
    this.withFields(instance.getFields()); 
    this.withIncludeSelectors(instance.getIncludeSelectors()); 
    this.withIncludeTemplates(instance.getIncludeTemplates()); 
    this.withPairs(instance.getPairs()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ArrayList<FieldSpecBuilder> fields = new ArrayList<FieldSpecBuilder>();
  private Boolean includeSelectors;
  private Boolean includeTemplates;
  private Map<String,String> pairs;
  private Map<String,Object> additionalProperties;
  public A addToFields(Integer index,FieldSpec item) {
    if (this.fields == null) {this.fields = new ArrayList<FieldSpecBuilder>();}
    FieldSpecBuilder builder = new FieldSpecBuilder(item);_visitables.get("fields").add(index >= 0 ? index : _visitables.get("fields").size(), builder);this.fields.add(index >= 0 ? index : fields.size(), builder); return (A)this;
  }
  public A setToFields(Integer index,FieldSpec item) {
    if (this.fields == null) {this.fields = new ArrayList<FieldSpecBuilder>();}
    FieldSpecBuilder builder = new FieldSpecBuilder(item);
    if (index < 0 || index >= _visitables.get("fields").size()) { _visitables.get("fields").add(builder); } else { _visitables.get("fields").set(index, builder);}
    if (index < 0 || index >= fields.size()) { fields.add(builder); } else { fields.set(index, builder);}
     return (A)this;
  }
  public A addToFields(io.fabric8.kubernetes.api.model.kustomize.v1beta1.FieldSpec... items) {
    if (this.fields == null) {this.fields = new ArrayList<FieldSpecBuilder>();}
    for (FieldSpec item : items) {FieldSpecBuilder builder = new FieldSpecBuilder(item);_visitables.get("fields").add(builder);this.fields.add(builder);} return (A)this;
  }
  public A addAllToFields(Collection<FieldSpec> items) {
    if (this.fields == null) {this.fields = new ArrayList<FieldSpecBuilder>();}
    for (FieldSpec item : items) {FieldSpecBuilder builder = new FieldSpecBuilder(item);_visitables.get("fields").add(builder);this.fields.add(builder);} return (A)this;
  }
  public A removeFromFields(io.fabric8.kubernetes.api.model.kustomize.v1beta1.FieldSpec... items) {
    for (FieldSpec item : items) {FieldSpecBuilder builder = new FieldSpecBuilder(item);_visitables.get("fields").remove(builder);if (this.fields != null) {this.fields.remove(builder);}} return (A)this;
  }
  public A removeAllFromFields(Collection<FieldSpec> items) {
    for (FieldSpec item : items) {FieldSpecBuilder builder = new FieldSpecBuilder(item);_visitables.get("fields").remove(builder);if (this.fields != null) {this.fields.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromFields(Predicate<FieldSpecBuilder> predicate) {
    if (fields == null) return (A) this;
    final Iterator<FieldSpecBuilder> each = fields.iterator();
    final List visitables = _visitables.get("fields");
    while (each.hasNext()) {
      FieldSpecBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildFields instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<FieldSpec> getFields() {
    return fields != null ? build(fields) : null;
  }
  public List<FieldSpec> buildFields() {
    return fields != null ? build(fields) : null;
  }
  public FieldSpec buildField(Integer index) {
    return this.fields.get(index).build();
  }
  public FieldSpec buildFirstField() {
    return this.fields.get(0).build();
  }
  public FieldSpec buildLastField() {
    return this.fields.get(fields.size() - 1).build();
  }
  public FieldSpec buildMatchingField(Predicate<FieldSpecBuilder> predicate) {
    for (FieldSpecBuilder item: fields) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingField(Predicate<FieldSpecBuilder> predicate) {
    for (FieldSpecBuilder item: fields) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withFields(List<FieldSpec> fields) {
    if (this.fields != null) { _visitables.get("fields").removeAll(this.fields);}
    if (fields != null) {this.fields = new ArrayList(); for (FieldSpec item : fields){this.addToFields(item);}} else { this.fields = null;} return (A) this;
  }
  public A withFields(io.fabric8.kubernetes.api.model.kustomize.v1beta1.FieldSpec... fields) {
    if (this.fields != null) {this.fields.clear();}
    if (fields != null) {for (FieldSpec item :fields){ this.addToFields(item);}} return (A) this;
  }
  public Boolean hasFields() {
    return fields != null && !fields.isEmpty();
  }
  public A addNewField(Boolean create,String group,String kind,String path,String version) {
    return (A)addToFields(new FieldSpec(create, group, kind, path, version));
  }
  public LabelFluent.FieldsNested<A> addNewField() {
    return new LabelFluentImpl.FieldsNestedImpl();
  }
  public LabelFluent.FieldsNested<A> addNewFieldLike(FieldSpec item) {
    return new LabelFluentImpl.FieldsNestedImpl(-1, item);
  }
  public LabelFluent.FieldsNested<A> setNewFieldLike(Integer index,FieldSpec item) {
    return new LabelFluentImpl.FieldsNestedImpl(index, item);
  }
  public LabelFluent.FieldsNested<A> editField(Integer index) {
    if (fields.size() <= index) throw new RuntimeException("Can't edit fields. Index exceeds size.");
    return setNewFieldLike(index, buildField(index));
  }
  public LabelFluent.FieldsNested<A> editFirstField() {
    if (fields.size() == 0) throw new RuntimeException("Can't edit first fields. The list is empty.");
    return setNewFieldLike(0, buildField(0));
  }
  public LabelFluent.FieldsNested<A> editLastField() {
    int index = fields.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last fields. The list is empty.");
    return setNewFieldLike(index, buildField(index));
  }
  public LabelFluent.FieldsNested<A> editMatchingField(Predicate<FieldSpecBuilder> predicate) {
    int index = -1;
    for (int i=0;i<fields.size();i++) { 
    if (predicate.test(fields.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching fields. No match found.");
    return setNewFieldLike(index, buildField(index));
  }
  public Boolean getIncludeSelectors() {
    return this.includeSelectors;
  }
  public A withIncludeSelectors(Boolean includeSelectors) {
    this.includeSelectors=includeSelectors; return (A) this;
  }
  public Boolean hasIncludeSelectors() {
    return this.includeSelectors != null;
  }
  public Boolean getIncludeTemplates() {
    return this.includeTemplates;
  }
  public A withIncludeTemplates(Boolean includeTemplates) {
    this.includeTemplates=includeTemplates; return (A) this;
  }
  public Boolean hasIncludeTemplates() {
    return this.includeTemplates != null;
  }
  public A addToPairs(String key,String value) {
    if(this.pairs == null && key != null && value != null) { this.pairs = new LinkedHashMap(); }
    if(key != null && value != null) {this.pairs.put(key, value);} return (A)this;
  }
  public A addToPairs(Map<String,String> map) {
    if(this.pairs == null && map != null) { this.pairs = new LinkedHashMap(); }
    if(map != null) { this.pairs.putAll(map);} return (A)this;
  }
  public A removeFromPairs(String key) {
    if(this.pairs == null) { return (A) this; }
    if(key != null && this.pairs != null) {this.pairs.remove(key);} return (A)this;
  }
  public A removeFromPairs(Map<String,String> map) {
    if(this.pairs == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.pairs != null){this.pairs.remove(key);}}} return (A)this;
  }
  public Map<String,String> getPairs() {
    return this.pairs;
  }
  public <K,V>A withPairs(Map<String,String> pairs) {
    if (pairs == null) { this.pairs =  null;} else {this.pairs = new LinkedHashMap(pairs);} return (A) this;
  }
  public Boolean hasPairs() {
    return this.pairs != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LabelFluentImpl that = (LabelFluentImpl) o;
    if (fields != null ? !fields.equals(that.fields) :that.fields != null) return false;
    if (includeSelectors != null ? !includeSelectors.equals(that.includeSelectors) :that.includeSelectors != null) return false;
    if (includeTemplates != null ? !includeTemplates.equals(that.includeTemplates) :that.includeTemplates != null) return false;
    if (pairs != null ? !pairs.equals(that.pairs) :that.pairs != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fields,  includeSelectors,  includeTemplates,  pairs,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fields != null && !fields.isEmpty()) { sb.append("fields:"); sb.append(fields + ","); }
    if (includeSelectors != null) { sb.append("includeSelectors:"); sb.append(includeSelectors + ","); }
    if (includeTemplates != null) { sb.append("includeTemplates:"); sb.append(includeTemplates + ","); }
    if (pairs != null && !pairs.isEmpty()) { sb.append("pairs:"); sb.append(pairs + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withIncludeSelectors() {
    return withIncludeSelectors(true);
  }
  public A withIncludeTemplates() {
    return withIncludeTemplates(true);
  }
  class FieldsNestedImpl<N> extends FieldSpecFluentImpl<LabelFluent.FieldsNested<N>> implements LabelFluent.FieldsNested<N>,Nested<N>{
    FieldsNestedImpl(Integer index,FieldSpec item) {
      this.index = index;
      this.builder = new FieldSpecBuilder(this, item);
    }
    FieldsNestedImpl() {
      this.index = -1;
      this.builder = new FieldSpecBuilder(this);
    }
    FieldSpecBuilder builder;
    Integer index;
    public N and() {
      return (N) LabelFluentImpl.this.setToFields(index,builder.build());
    }
    public N endField() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-kustomize-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/LabelFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LabelFluentImpl<A extends LabelFluent<A>> extends BaseFluent<A> implements LabelFluent<A>{
  public LabelFluentImpl() {
  }
  public LabelFluentImpl(Label instance) {
    if (instance != null) {
      this.withFields(instance.getFields());
      this.withIncludeSelectors(instance.getIncludeSelectors());
      this.withIncludeTemplates(instance.getIncludeTemplates());
      this.withPairs(instance.getPairs());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ArrayList<FieldSpecBuilder> fields = new ArrayList<FieldSpecBuilder>();
  private Boolean includeSelectors;
  private Boolean includeTemplates;
  private Map<String,String> pairs;
  private Map<String,Object> additionalProperties;
  public A addToFields(int index,FieldSpec item) {
    if (this.fields == null) {this.fields = new ArrayList<FieldSpecBuilder>();}
    FieldSpecBuilder builder = new FieldSpecBuilder(item);
    if (index < 0 || index >= fields.size()) { _visitables.get("fields").add(builder); fields.add(builder); } else { _visitables.get("fields").add(index, builder); fields.add(index, builder);}
    return (A)this;
  }
  public A setToFields(int index,FieldSpec item) {
    if (this.fields == null) {this.fields = new ArrayList<FieldSpecBuilder>();}
    FieldSpecBuilder builder = new FieldSpecBuilder(item);
    if (index < 0 || index >= fields.size()) { _visitables.get("fields").add(builder); fields.add(builder); } else { _visitables.get("fields").set(index, builder); fields.set(index, builder);}
    return (A)this;
  }
  public A addToFields(io.fabric8.kubernetes.api.model.kustomize.v1beta1.FieldSpec... items) {
    if (this.fields == null) {this.fields = new ArrayList<FieldSpecBuilder>();}
    for (FieldSpec item : items) {FieldSpecBuilder builder = new FieldSpecBuilder(item);_visitables.get("fields").add(builder);this.fields.add(builder);} return (A)this;
  }
  public A addAllToFields(Collection<FieldSpec> items) {
    if (this.fields == null) {this.fields = new ArrayList<FieldSpecBuilder>();}
    for (FieldSpec item : items) {FieldSpecBuilder builder = new FieldSpecBuilder(item);_visitables.get("fields").add(builder);this.fields.add(builder);} return (A)this;
  }
  public A removeFromFields(io.fabric8.kubernetes.api.model.kustomize.v1beta1.FieldSpec... items) {
    for (FieldSpec item : items) {FieldSpecBuilder builder = new FieldSpecBuilder(item);_visitables.get("fields").remove(builder);if (this.fields != null) {this.fields.remove(builder);}} return (A)this;
  }
  public A removeAllFromFields(Collection<FieldSpec> items) {
    for (FieldSpec item : items) {FieldSpecBuilder builder = new FieldSpecBuilder(item);_visitables.get("fields").remove(builder);if (this.fields != null) {this.fields.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromFields(Predicate<FieldSpecBuilder> predicate) {
    if (fields == null) return (A) this;
    final Iterator<FieldSpecBuilder> each = fields.iterator();
    final List visitables = _visitables.get("fields");
    while (each.hasNext()) {
      FieldSpecBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildFields instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<FieldSpec> getFields() {
    return fields != null ? build(fields) : null;
  }
  public List<FieldSpec> buildFields() {
    return fields != null ? build(fields) : null;
  }
  public FieldSpec buildField(int index) {
    return this.fields.get(index).build();
  }
  public FieldSpec buildFirstField() {
    return this.fields.get(0).build();
  }
  public FieldSpec buildLastField() {
    return this.fields.get(fields.size() - 1).build();
  }
  public FieldSpec buildMatchingField(Predicate<FieldSpecBuilder> predicate) {
    for (FieldSpecBuilder item: fields) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingField(Predicate<FieldSpecBuilder> predicate) {
    for (FieldSpecBuilder item: fields) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withFields(List<FieldSpec> fields) {
    if (this.fields != null) { _visitables.get("fields").clear();}
    if (fields != null) {this.fields = new ArrayList(); for (FieldSpec item : fields){this.addToFields(item);}} else { this.fields = null;} return (A) this;
  }
  public A withFields(io.fabric8.kubernetes.api.model.kustomize.v1beta1.FieldSpec... fields) {
    if (this.fields != null) {this.fields.clear(); _visitables.remove("fields"); }
    if (fields != null) {for (FieldSpec item :fields){ this.addToFields(item);}} return (A) this;
  }
  public Boolean hasFields() {
    return fields != null && !fields.isEmpty();
  }
  public A addNewField(Boolean create,String group,String kind,String path,String version) {
    return (A)addToFields(new FieldSpec(create, group, kind, path, version));
  }
  public LabelFluentImpl.FieldsNested<A> addNewField() {
    return new LabelFluentImpl.FieldsNestedImpl();
  }
  public LabelFluentImpl.FieldsNested<A> addNewFieldLike(FieldSpec item) {
    return new LabelFluentImpl.FieldsNestedImpl(-1, item);
  }
  public LabelFluentImpl.FieldsNested<A> setNewFieldLike(int index,FieldSpec item) {
    return new LabelFluentImpl.FieldsNestedImpl(index, item);
  }
  public LabelFluentImpl.FieldsNested<A> editField(int index) {
    if (fields.size() <= index) throw new RuntimeException("Can't edit fields. Index exceeds size.");
    return setNewFieldLike(index, buildField(index));
  }
  public LabelFluentImpl.FieldsNested<A> editFirstField() {
    if (fields.size() == 0) throw new RuntimeException("Can't edit first fields. The list is empty.");
    return setNewFieldLike(0, buildField(0));
  }
  public LabelFluentImpl.FieldsNested<A> editLastField() {
    int index = fields.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last fields. The list is empty.");
    return setNewFieldLike(index, buildField(index));
  }
  public LabelFluentImpl.FieldsNested<A> editMatchingField(Predicate<FieldSpecBuilder> predicate) {
    int index = -1;
    for (int i=0;i<fields.size();i++) { 
    if (predicate.test(fields.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching fields. No match found.");
    return setNewFieldLike(index, buildField(index));
  }
  public Boolean getIncludeSelectors() {
    return this.includeSelectors;
  }
  public A withIncludeSelectors(Boolean includeSelectors) {
    this.includeSelectors=includeSelectors; return (A) this;
  }
  public Boolean hasIncludeSelectors() {
    return this.includeSelectors != null;
  }
  public Boolean getIncludeTemplates() {
    return this.includeTemplates;
  }
  public A withIncludeTemplates(Boolean includeTemplates) {
    this.includeTemplates=includeTemplates; return (A) this;
  }
  public Boolean hasIncludeTemplates() {
    return this.includeTemplates != null;
  }
  public A addToPairs(String key,String value) {
    if(this.pairs == null && key != null && value != null) { this.pairs = new LinkedHashMap(); }
    if(key != null && value != null) {this.pairs.put(key, value);} return (A)this;
  }
  public A addToPairs(Map<String,String> map) {
    if(this.pairs == null && map != null) { this.pairs = new LinkedHashMap(); }
    if(map != null) { this.pairs.putAll(map);} return (A)this;
  }
  public A removeFromPairs(String key) {
    if(this.pairs == null) { return (A) this; }
    if(key != null && this.pairs != null) {this.pairs.remove(key);} return (A)this;
  }
  public A removeFromPairs(Map<String,String> map) {
    if(this.pairs == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.pairs != null){this.pairs.remove(key);}}} return (A)this;
  }
  public Map<String,String> getPairs() {
    return this.pairs;
  }
  public <K,V>A withPairs(Map<String,String> pairs) {
    if (pairs == null) { this.pairs =  null;} else {this.pairs = new LinkedHashMap(pairs);} return (A) this;
  }
  public Boolean hasPairs() {
    return this.pairs != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LabelFluentImpl that = (LabelFluentImpl) o;
    if (!java.util.Objects.equals(fields, that.fields)) return false;

    if (!java.util.Objects.equals(includeSelectors, that.includeSelectors)) return false;

    if (!java.util.Objects.equals(includeTemplates, that.includeTemplates)) return false;

    if (!java.util.Objects.equals(pairs, that.pairs)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fields,  includeSelectors,  includeTemplates,  pairs,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fields != null) { sb.append("fields:"); sb.append(fields + ","); }
    if (includeSelectors != null) { sb.append("includeSelectors:"); sb.append(includeSelectors + ","); }
    if (includeTemplates != null) { sb.append("includeTemplates:"); sb.append(includeTemplates + ","); }
    if (pairs != null && !pairs.isEmpty()) { sb.append("pairs:"); sb.append(pairs + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withIncludeSelectors() {
    return withIncludeSelectors(true);
  }
  public A withIncludeTemplates() {
    return withIncludeTemplates(true);
  }
  class FieldsNestedImpl<N> extends FieldSpecFluentImpl<LabelFluentImpl.FieldsNested<N>> implements LabelFluentImpl.FieldsNested<N>,Nested<N>{
    FieldsNestedImpl(int index,FieldSpec item) {
      this.index = index;
      this.builder = new FieldSpecBuilder(this, item);
    }
    FieldsNestedImpl() {
      this.index = -1;
      this.builder = new FieldSpecBuilder(this);
    }
    FieldSpecBuilder builder;
    int index;
    public N and() {
      return (N) LabelFluentImpl.this.setToFields(index,builder.build());
    }
    public N endField() {
      return and();
    }
    
  }
  
}
